/* ============================================================================
 * Freetype GL - A C OpenGL Freetype engine
 * Platform:    Any
 * WWW:         http://code.google.com/p/freetype-gl/
 * ----------------------------------------------------------------------------
 * Copyright 2011,2012 Nicolas P. Rougier. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY NICOLAS P. ROUGIER ''AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL NICOLAS P. ROUGIER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of Nicolas P. Rougier.
 * ===============================================================================
 */
#include <stddef.h>
#ifdef __cplusplus
extern "C" {
#endif

typedef struct
{
    wchar_t charcode;
    float kerning;
} kerning_t;

typedef struct
{
    wchar_t charcode;
    int width, height;
    int offset_x, offset_y;
    float advance_x, advance_y;
    float s0, t0, s1, t1;
    size_t kerning_count;
    kerning_t kerning[10];
} texture_glyph_t;

typedef struct
{
    size_t tex_width;
    size_t tex_height;
    size_t tex_depth;
    char tex_data[16384];
    float size;
    float height;
    float linegap;
    float ascender;
    float descender;
    size_t glyphs_count;
    texture_glyph_t glyphs[96];
} texture_font_t;

texture_font_t font = {
 128, 128, 1, 
 {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,255,255,255,255,0,0,104,236,0,0,68,255,88,172,240,0,0,0,0,232,67,0,69,230,0,0,0,0,4,54,221,
  40,0,0,0,0,0,55,211,243,176,19,0,0,0,159,133,0,0,0,0,0,0,8,146,234,232,131,1,0,0,0,0,
  76,255,80,0,0,0,0,147,120,0,0,192,74,0,0,0,0,0,121,154,0,0,0,0,0,0,0,252,88,0,0,0,
  0,32,56,1,0,2,4,4,4,3,0,30,56,3,0,0,0,0,207,80,0,0,0,96,217,247,203,64,0,0,0,0,
  0,255,255,255,255,0,0,104,236,0,0,67,255,87,171,239,0,0,0,34,252,12,0,128,173,0,0,0,50,220,251,253,
  255,182,8,0,0,0,218,160,68,205,151,0,0,40,236,16,0,0,0,0,0,0,139,236,83,109,254,95,0,0,0,0,
  75,255,79,0,0,0,59,225,8,0,0,52,226,14,0,0,46,121,119,140,98,74,0,0,0,0,0,252,88,0,0,0,
  0,148,255,8,0,128,255,255,255,212,0,140,255,16,0,0,0,23,250,14,0,0,85,254,133,73,176,246,41,0,0,0,
  0,255,255,255,255,0,0,104,236,0,0,38,255,59,142,210,0,0,0,91,208,0,0,187,116,0,0,1,218,198,26,208,
  62,248,132,0,0,10,255,48,0,112,201,0,0,170,123,0,0,0,0,0,0,0,211,160,0,0,214,152,0,0,0,0,
  50,255,52,0,0,0,198,115,0,0,0,0,189,125,0,0,56,175,241,246,184,81,0,0,4,4,4,252,90,4,4,1,
  0,0,215,3,0,26,52,52,52,43,0,0,0,0,0,0,0,93,195,0,0,0,214,159,0,0,3,211,158,0,0,0,
  0,255,255,255,255,0,0,104,236,0,0,2,244,17,95,166,0,216,255,255,255,255,255,255,255,176,0,35,255,73,4,208,
  0,133,131,0,0,0,234,117,15,175,169,0,49,232,12,0,0,0,0,0,0,0,175,233,21,45,249,95,0,0,0,0,
  8,250,9,0,0,57,254,28,0,0,0,0,101,233,7,0,0,43,222,216,72,0,0,28,255,255,255,255,255,255,255,116,
  0,80,186,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,124,0,0,26,255,81,0,0,0,132,230,0,0,0,
  0,0,0,0,0,0,0,104,236,0,0,0,0,0,0,0,0,47,56,213,133,56,88,253,63,38,0,31,255,91,4,208,
  0,0,0,0,0,0,90,247,255,223,39,0,182,113,0,0,0,0,0,0,0,0,40,244,212,242,155,2,0,0,0,0,
  0,0,0,0,0,146,201,0,0,0,0,0,20,255,73,0,0,158,113,77,199,0,0,5,52,52,52,252,122,52,52,23,
  0,36,13,0,0,0,0,0,69,243,0,0,0,0,0,0,1,233,53,0,0,66,255,45,0,0,0,97,255,12,0,0,
  0,148,255,8,0,0,0,104,236,0,0,0,0,0,0,0,0,0,3,245,51,0,89,213,0,0,0,0,202,231,87,208,
  0,0,0,0,0,0,0,14,39,5,0,59,228,8,110,212,183,34,0,0,0,0,66,225,255,185,0,0,0,0,0,0,
  144,255,12,0,0,211,151,0,0,0,0,0,0,225,138,0,0,3,3,0,7,0,0,0,0,0,0,252,88,0,0,0,
  0,0,0,0,0,0,0,50,238,244,0,0,0,0,0,0,50,236,2,0,0,81,255,32,0,0,0,84,255,26,0,0,
  0,32,56,1,0,0,0,104,236,0,0,0,0,0,0,0,0,3,49,248,9,4,143,160,4,2,0,0,26,177,255,252,
  195,92,0,0,0,0,0,0,0,0,0,192,103,61,238,54,138,201,0,0,0,98,254,143,145,255,93,6,130,45,0,0,
  31,56,2,0,0,243,122,0,0,0,0,0,0,194,170,0,0,0,0,0,0,0,0,0,0,0,0,252,88,0,0,0,
  0,0,0,0,0,5,111,246,238,244,0,0,0,0,0,0,121,168,0,0,0,82,255,31,0,0,0,84,255,24,0,0,
  0,0,0,0,0,0,0,104,236,0,0,0,0,0,0,0,0,216,255,255,255,255,255,255,255,176,0,0,0,0,31,231,
  193,255,116,0,0,0,0,0,0,0,71,221,5,142,166,0,22,255,28,0,20,245,146,0,3,189,245,123,255,74,0,0,
  0,0,0,0,2,255,112,0,0,0,0,0,0,184,185,0,0,0,0,0,0,0,0,0,0,0,0,252,88,0,0,0,
  0,0,0,0,0,68,242,118,118,244,0,0,0,0,0,0,192,97,0,0,0,67,255,44,0,0,0,97,255,9,0,0,
  0,0,0,0,0,0,0,104,236,0,0,0,0,0,0,0,0,43,171,171,52,52,247,94,52,35,0,0,0,0,4,208,
  0,157,243,3,0,0,0,0,0,0,203,93,0,164,148,0,5,255,51,0,68,255,63,0,0,20,224,255,222,5,0,0,
  0,0,0,0,0,239,127,0,0,0,0,0,0,201,166,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,24,20,0,116,244,0,0,0,0,0,13,250,27,0,0,0,30,255,78,0,0,0,133,226,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,107,0,31,254,13,0,0,0,48,160,12,4,208,
  0,85,255,28,0,0,0,0,0,82,213,2,0,142,171,0,28,255,29,0,37,255,120,0,0,0,130,255,201,7,0,0,
  0,0,0,0,0,210,155,0,0,0,0,0,0,228,136,0,0,5,121,217,245,212,102,1,0,0,0,5,128,224,246,193,
  55,0,0,0,0,0,0,0,116,244,0,0,0,0,0,78,212,0,0,0,0,0,217,158,0,0,3,211,159,0,0,0,
  0,0,0,0,0,0,0,31,56,3,0,0,0,0,0,0,0,0,238,61,0,76,223,0,0,0,0,61,255,86,4,208,
  0,133,247,3,0,0,0,0,2,213,83,0,0,69,245,86,160,207,0,0,0,167,247,114,67,148,254,183,254,181,12,0,
  0,0,0,0,0,143,212,0,0,0,0,0,28,255,67,0,0,141,245,117,67,134,254,110,0,0,0,141,244,109,69,174,
  244,37,0,0,0,0,0,0,116,244,0,0,0,0,0,149,141,0,0,0,0,0,95,255,139,73,175,246,42,0,0,0,
  0,0,0,0,0,0,0,144,255,16,0,0,0,0,0,0,0,29,255,15,0,121,178,0,0,0,0,1,204,236,92,217,
  111,248,135,0,0,0,0,0,93,205,1,0,0,0,130,237,206,44,0,0,0,8,142,231,249,207,93,0,95,201,12,0,
  0,0,0,0,0,61,254,28,0,0,0,0,99,236,5,0,9,249,119,0,0,0,158,226,0,0,11,246,122,0,0,7,
  240,132,0,0,0,0,0,0,116,244,0,0,0,0,0,220,71,0,0,0,0,0,0,108,223,247,202,63,0,0,0,0,
  0,32,56,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,167,244,255,
  224,128,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,
  31,56,2,0,0,0,199,124,0,0,0,0,198,124,0,0,25,149,41,0,0,0,118,255,4,0,3,48,19,0,0,1,
  239,139,0,0,0,0,0,0,116,244,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,148,255,8,0,0,0,0,0,0,9,218,148,0,0,0,0,16,255,255,255,255,255,184,0,0,0,0,0,0,6,208,
  0,0,0,0,0,0,0,106,217,244,203,69,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  144,255,12,0,0,0,66,228,9,0,0,56,231,14,0,0,0,0,0,0,0,0,195,219,0,0,0,0,0,2,32,156,
  247,44,0,0,0,0,0,0,116,244,0,0,0,74,204,247,224,122,1,0,0,64,255,255,255,255,255,255,255,43,0,0,
  0,0,215,3,0,0,0,0,0,0,140,255,148,0,0,0,0,62,255,72,56,56,56,40,0,0,0,0,0,0,4,208,
  0,0,0,0,0,0,101,254,129,68,161,251,52,0,0,0,8,141,231,244,189,53,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,151,122,0,0,194,78,0,0,0,0,0,0,0,0,108,255,101,0,0,0,0,0,119,255,255,
  133,1,0,0,0,0,0,0,116,244,0,0,69,252,151,66,123,251,118,0,0,14,56,56,56,56,61,230,195,4,0,0,
  0,80,186,0,0,0,0,0,0,54,244,236,148,0,0,0,0,108,235,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,199,174,0,0,2,220,152,0,0,0,175,247,123,69,142,245,50,0,0,0,0,0,0,0,0,0,
  0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,253,163,0,0,0,0,0,0,43,63,128,
  252,143,0,0,0,0,0,0,116,244,0,0,205,163,0,0,0,147,185,0,0,0,0,0,0,0,135,241,27,0,0,0,
  0,36,13,0,0,0,0,0,6,213,122,212,148,0,0,0,0,154,190,0,0,0,0,0,0,0,28,255,255,255,255,255,
  255,255,116,0,0,0,214,160,0,0,0,203,170,0,0,43,255,113,0,0,0,167,186,0,0,0,0,0,0,0,0,57,
  172,117,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,121,255,167,4,0,0,0,0,0,0,0,0,0,
  145,252,14,0,0,0,0,0,0,0,0,29,255,58,0,0,0,0,0,0,0,0,0,0,0,38,250,115,0,0,0,0,
  0,0,0,0,0,0,0,0,132,208,4,212,148,0,0,0,0,200,197,195,248,231,127,2,0,0,6,56,56,56,56,56,
  56,56,25,0,0,0,122,245,73,15,105,254,82,0,0,81,255,41,0,0,0,107,251,7,0,0,0,0,3,83,198,255,
  204,57,0,32,210,96,6,0,0,0,0,0,0,0,0,0,0,0,144,255,151,2,0,0,0,0,21,96,17,0,0,0,
  96,255,36,0,0,0,0,0,0,0,0,74,255,55,187,249,232,120,0,0,0,0,0,0,0,171,223,5,0,0,0,0,
  0,132,255,0,0,0,0,48,247,52,0,212,148,0,0,0,1,244,236,96,64,137,252,142,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,2,171,255,255,255,130,0,0,0,52,255,71,0,0,0,140,255,34,0,0,12,110,222,252,172,60,
  0,0,0,12,166,250,231,123,18,0,0,0,0,0,0,0,0,123,255,133,0,0,0,0,0,0,32,255,105,0,0,0,
  164,241,6,0,0,0,0,0,0,0,0,95,255,226,129,65,135,253,107,0,0,0,0,0,32,253,109,0,0,0,0,0,
  0,132,255,0,0,0,4,206,140,0,0,212,148,0,0,0,2,64,35,0,0,0,147,251,18,0,0,4,4,4,4,4,
  4,4,1,0,0,0,162,238,106,64,132,251,108,0,0,4,209,218,58,15,85,238,255,45,0,23,239,239,139,31,0,0,
  0,0,0,0,0,27,134,236,245,149,37,0,0,0,0,0,34,251,201,56,56,56,56,56,3,0,0,164,241,106,69,150,
  255,109,0,0,0,0,0,0,0,0,0,100,255,138,0,0,0,158,234,0,0,0,0,0,134,242,11,0,0,0,0,0,
  0,132,255,0,0,0,122,223,14,4,4,212,149,4,0,0,0,0,0,0,0,0,75,255,60,0,28,255,255,255,255,255,
  255,255,116,0,0,48,255,89,0,0,0,136,244,10,0,0,37,202,255,255,210,111,255,35,0,22,237,239,138,29,0,0,
  0,0,0,0,0,0,0,9,101,211,253,96,0,0,0,0,110,255,255,255,255,255,255,255,16,0,0,8,132,222,249,210,
  92,0,0,0,0,0,0,0,0,0,0,88,255,66,0,0,0,87,255,23,0,0,0,0,216,164,0,0,0,0,0,0,
  0,132,255,0,0,0,204,255,255,255,255,255,255,255,32,0,25,101,23,0,0,0,84,255,40,0,5,52,52,52,52,52,
  52,52,23,0,0,85,255,33,0,0,0,76,255,40,0,0,0,0,26,37,0,98,255,17,0,0,11,109,221,251,169,56,
  0,0,0,0,0,0,0,8,99,211,253,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,52,255,73,0,0,0,92,255,22,0,0,0,34,255,82,0,0,0,0,0,0,
  0,132,255,0,0,0,41,52,52,52,52,220,169,52,6,0,29,255,117,0,0,0,167,228,4,0,0,0,0,0,0,0,
  0,0,0,0,0,52,255,92,0,0,0,131,249,13,0,6,90,29,0,0,0,145,225,0,0,0,0,0,3,85,200,255,
  200,55,0,0,0,25,131,234,245,148,35,0,0,0,4,121,218,245,210,99,1,0,0,0,0,0,0,12,112,192,236,250,
  230,191,103,10,0,0,0,0,0,0,0,4,234,161,0,0,0,167,219,0,0,0,0,88,255,26,0,0,0,0,0,0,
  0,132,255,0,0,0,0,0,0,0,0,212,148,0,0,0,0,162,245,113,70,153,255,92,0,0,212,255,255,255,253,232,
  161,23,0,0,0,0,183,239,107,65,129,250,136,0,0,1,237,124,0,0,19,233,149,0,0,0,0,0,0,0,0,61,
  176,117,0,12,162,249,232,124,18,0,0,0,0,0,140,249,122,68,142,255,115,0,0,0,0,0,47,227,234,140,88,63,
  84,141,233,214,43,0,0,0,0,0,0,0,101,255,141,67,141,254,93,0,0,0,0,132,243,0,0,0,0,0,0,0,
  0,132,255,0,0,0,0,0,0,0,0,212,148,0,0,0,0,8,132,222,248,210,89,0,0,0,212,193,56,56,62,97,
  227,200,0,0,0,0,8,130,218,245,210,103,1,0,0,0,134,241,98,73,202,234,28,0,0,0,0,0,0,0,0,0,
  0,4,0,32,214,100,7,0,0,0,0,0,0,13,251,133,0,0,0,161,236,0,0,0,0,51,241,151,7,0,0,0,
  0,0,15,168,227,19,0,0,0,0,0,0,0,94,213,249,217,97,0,0,0,0,0,154,227,0,0,0,0,0,0,0,
  0,132,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,176,0,0,0,0,
  91,255,47,0,0,0,0,0,0,0,0,0,0,0,0,0,6,137,229,240,179,41,0,0,0,0,0,0,0,0,0,0,
  0,0,0,3,1,0,0,0,0,0,0,0,0,32,163,42,0,0,0,106,255,14,0,0,4,208,142,0,10,146,236,226,
  91,146,210,3,191,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,132,255,0,0,0,0,0,0,0,207,255,54,0,0,0,0,0,0,0,0,0,0,0,0,0,212,176,0,0,0,0,
  75,255,47,0,196,255,255,255,252,235,180,62,0,0,0,0,0,0,0,0,0,0,0,0,0,188,255,255,255,255,255,255,
  255,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,186,219,0,0,0,99,217,6,3,192,221,83,90,
  231,228,160,0,59,245,11,0,0,0,0,75,183,233,243,207,108,5,0,0,176,255,255,255,255,255,255,255,12,0,0,0,
  0,132,255,0,0,0,0,0,0,44,254,213,154,0,0,0,0,0,0,0,0,0,0,0,0,0,212,177,4,4,7,41,
  198,193,0,0,196,206,56,56,61,85,186,253,81,0,0,0,0,0,0,0,196,192,0,0,0,188,212,56,56,56,56,56,
  56,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,151,252,70,0,0,0,189,116,0,107,248,36,0,0,
  100,255,110,0,1,247,48,0,0,0,139,252,157,79,68,133,247,171,3,0,176,221,56,56,56,56,56,56,2,0,0,0,
  0,132,255,0,0,0,0,0,0,139,207,113,242,11,0,0,0,0,0,0,0,0,0,0,0,0,212,255,255,255,255,255,
  238,44,0,0,196,192,0,0,0,0,1,187,235,11,0,0,0,0,0,0,196,192,0,0,0,188,200,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,253,92,0,0,0,1,250,45,0,213,161,0,0,0,
  55,255,60,0,0,234,64,0,0,82,255,98,0,0,0,0,91,255,90,0,176,212,0,0,0,0,0,0,0,0,0,0,
  0,132,255,0,0,0,0,0,3,229,135,26,253,98,0,0,0,0,0,0,0,0,0,0,0,0,212,192,52,52,55,81,
  192,240,45,0,196,192,0,0,0,0,0,62,255,90,0,0,0,0,0,0,196,192,0,0,0,188,200,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,248,121,0,0,0,0,23,255,15,17,255,94,0,0,0,
  77,253,12,0,21,254,33,0,0,199,205,0,0,0,0,0,1,142,72,0,176,212,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,71,255,44,0,186,198,0,0,0,0,0,0,0,0,0,0,0,0,212,176,0,0,0,0,
  10,238,167,0,196,192,0,0,0,0,0,1,250,148,0,0,0,0,0,0,196,192,0,0,0,188,200,4,4,4,4,4,
  4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,255,26,0,0,0,0,23,255,23,32,255,81,0,0,0,
  154,215,0,0,121,213,0,0,14,255,131,0,0,0,0,0,0,0,0,0,176,212,4,4,4,4,4,0,0,0,0,0,
  0,0,0,0,0,0,0,0,165,206,0,0,92,255,42,0,0,0,0,0,0,0,0,0,0,0,212,176,0,0,0,0,
  0,202,204,0,196,192,0,0,0,0,0,0,229,171,0,0,0,0,0,0,196,192,0,0,0,188,255,255,255,255,255,255,
  255,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,124,6,0,0,0,0,2,247,58,6,244,136,0,0,54,
  250,166,0,54,245,82,0,0,41,255,100,0,0,0,0,0,0,0,0,0,176,255,255,255,255,255,255,52,0,0,0,0,
  0,0,0,0,0,0,0,13,245,124,16,16,26,245,142,0,0,0,0,0,0,0,0,0,0,0,212,176,0,0,0,0,
  12,243,168,0,196,192,0,0,0,0,0,0,229,171,0,0,0,0,0,0,196,192,0,0,0,188,211,52,52,52,52,52,
  52,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,56,11,0,0,0,0,0,179,150,0,149,249,132,129,227,
  247,208,131,245,141,0,0,0,38,255,102,0,0,0,0,0,0,0,0,0,176,220,52,52,52,52,52,10,0,0,0,0,
  0,0,0,0,0,0,0,97,255,255,255,255,255,255,235,6,0,0,0,0,0,0,0,0,0,0,212,193,56,56,56,74,
  192,251,56,0,196,192,0,0,0,0,0,5,249,144,0,0,0,0,0,0,196,192,0,0,0,188,200,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,255,52,0,0,0,0,0,72,247,55,10,162,244,204,45,
  141,245,216,100,0,41,28,0,11,252,132,0,0,0,0,0,0,25,2,0,176,212,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,191,202,64,64,64,64,107,255,86,0,0,0,0,0,0,0,0,0,0,212,255,255,255,254,240,
  190,67,0,0,196,192,0,0,0,0,0,61,255,84,0,0,0,0,0,0,196,192,0,0,0,188,200,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,151,235,83,0,0,0,0,
  0,0,0,11,140,241,49,0,0,194,204,0,0,0,0,0,0,217,186,0,176,212,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,30,254,109,0,0,0,0,3,231,186,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,196,192,0,0,0,0,1,184,230,9,0,61,122,0,0,0,199,184,0,0,0,188,200,0,0,0,0,0,
  0,0,0,0,0,0,53,163,224,248,234,174,56,0,0,0,0,0,0,0,0,0,0,0,0,2,130,252,207,129,84,62,
  69,92,152,233,210,47,0,0,0,82,255,95,0,0,0,0,97,255,97,0,176,212,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,123,253,25,0,0,0,0,0,144,253,31,0,184,204,0,0,0,0,0,64,255,68,0,0,0,0,
  0,0,0,0,196,206,56,56,60,87,184,251,76,0,0,113,244,6,0,0,225,157,0,0,0,188,212,56,56,56,56,56,
  56,45,0,0,0,105,252,182,89,62,89,192,252,79,0,0,0,0,0,0,0,0,0,0,0,0,0,32,132,195,234,251,
  244,222,169,84,4,0,0,0,0,0,158,253,152,75,73,146,251,168,1,0,176,212,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,216,194,0,0,0,0,0,0,53,255,130,0,184,204,0,0,0,0,0,64,255,68,0,0,0,0,
  0,0,0,0,196,255,255,255,250,224,176,56,0,0,0,38,251,155,65,141,255,73,0,0,0,188,255,255,255,255,255,255,
  255,208,0,0,50,251,142,0,0,0,0,2,181,230,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,1,97,198,237,243,205,104,4,0,0,176,212,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,204,0,0,0,0,0,64,255,68,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,81,211,247,219,102,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,169,228,9,0,0,0,0,0,51,169,23,0,212,176,0,0,0,0,45,237,216,24,0,212,176,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,208,255,160,0,0,0,0,0,24,253,255,32,0,0,184,204,0,0,0,0,0,64,255,68,0,196,255,255,
  255,255,245,207,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,244,32,0,0,0,0,52,255,
  64,0,0,2,245,151,0,0,0,0,0,0,0,0,0,0,212,176,0,0,0,38,232,217,25,0,0,212,176,0,0,0,
  0,0,0,0,0,0,0,72,184,238,245,213,126,15,0,0,0,0,0,0,80,186,234,244,208,117,10,0,0,0,0,0,
  0,0,0,0,208,254,237,4,0,0,0,0,106,255,255,32,0,0,184,204,4,4,4,4,4,67,255,68,0,196,206,56,
  56,56,67,156,255,100,0,192,255,255,255,255,252,236,180,44,0,0,0,0,0,0,0,200,255,184,0,0,0,0,52,255,
  64,0,0,25,255,115,0,0,0,1,4,4,4,4,1,0,212,176,0,0,32,227,219,26,0,0,0,212,176,0,0,0,
  0,0,0,0,0,0,132,255,167,80,66,118,231,217,32,0,0,0,0,149,253,156,76,68,125,237,206,23,0,0,0,0,
  0,0,0,0,208,197,254,68,0,0,0,0,190,209,255,32,0,0,184,255,255,255,255,255,255,255,255,68,0,196,192,0,
  0,0,0,0,206,211,0,192,209,56,56,56,61,102,228,231,11,0,0,0,0,0,0,200,240,255,93,0,0,0,52,255,
  64,0,0,28,255,115,0,0,0,104,255,255,255,255,112,0,212,176,0,26,221,220,27,0,0,0,0,212,176,0,0,0,
  0,0,0,0,0,81,255,104,0,0,0,0,27,224,195,1,0,0,95,255,87,0,0,0,0,36,235,176,0,0,0,0,
  0,0,0,0,208,168,201,150,0,0,0,21,252,124,255,32,0,0,184,214,52,52,52,52,52,103,255,68,0,196,192,0,
  0,0,0,0,157,243,0,192,196,0,0,0,0,0,76,255,82,0,0,0,0,0,0,200,172,187,235,20,0,0,52,255,
  64,0,0,3,249,146,0,0,0,21,52,52,61,255,112,0,212,176,21,215,226,29,0,0,0,0,0,212,176,0,0,0,
  0,0,0,0,0,203,199,0,0,0,0,0,0,88,255,64,0,0,216,180,0,0,0,0,0,0,108,255,41,0,0,0,
  0,0,0,0,208,168,118,230,1,0,0,102,207,88,255,32,0,0,184,204,0,0,0,0,0,64,255,68,0,196,192,0,
  0,0,0,0,194,210,0,192,196,0,0,0,0,0,63,255,82,0,0,0,0,0,0,200,172,34,246,165,0,0,52,255,
  64,0,0,0,177,224,4,0,0,0,0,0,12,255,112,0,212,192,207,254,241,32,0,0,0,0,0,212,176,0,0,0,
  0,0,0,0,18,254,125,0,0,0,0,0,0,10,250,139,0,36,255,102,0,0,0,0,0,0,25,255,118,0,0,0,
  0,0,0,0,208,168,35,255,58,0,0,186,122,88,255,32,0,0,184,204,0,0,0,0,0,64,255,68,0,196,193,4,
  4,5,28,126,255,108,0,192,196,4,4,4,11,56,207,231,16,0,0,0,0,0,0,200,172,0,117,255,72,0,52,255,
  64,0,0,0,56,252,140,1,0,0,0,0,54,255,112,0,212,255,224,59,240,195,2,0,0,0,0,212,176,0,0,0,
  0,0,0,0,49,255,93,0,0,0,0,0,0,0,228,170,0,67,255,71,0,0,0,0,0,0,0,247,149,0,0,0,
  0,0,0,0,208,168,0,208,140,0,18,251,38,88,255,32,0,0,184,204,0,0,0,0,0,64,255,68,0,196,255,255,
  255,255,255,245,140,3,0,192,255,255,255,255,255,249,185,41,0,0,0,0,0,0,0,200,172,0,4,206,224,12,52,255,
  64,0,0,0,0,100,249,193,97,63,84,162,251,225,52,0,212,230,34,0,97,255,122,0,0,0,0,212,176,0,0,0,
  0,0,0,0,50,255,89,0,0,0,0,0,0,0,224,170,0,67,255,71,0,0,0,0,0,0,0,245,154,0,0,0,
  0,0,0,0,208,168,0,125,221,0,98,209,0,88,255,32,0,0,184,204,0,0,0,0,0,64,255,68,0,196,205,52,
  52,51,39,5,0,0,0,192,208,52,52,88,228,185,13,0,0,0,0,0,0,0,0,200,172,0,0,50,252,144,52,255,
  64,0,0,0,0,0,44,153,220,248,238,191,106,10,0,0,212,176,0,0,0,181,250,51,0,0,0,212,176,0,0,0,
  0,0,0,0,19,255,119,0,0,0,0,0,0,7,249,141,0,36,255,104,0,0,0,0,0,0,22,255,126,0,0,0,
  0,0,0,0,208,168,0,42,255,47,181,124,0,88,255,32,0,0,184,204,0,0,0,0,0,64,255,68,0,196,192,0,
  0,0,0,0,0,0,0,192,196,0,0,0,50,250,180,0,0,0,0,0,0,0,0,200,172,0,0,0,139,253,106,255,
  64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,176,0,0,0,26,239,215,9,0,0,212,176,0,0,0,
  0,0,0,0,0,198,201,0,0,0,0,0,0,81,255,66,0,0,215,184,0,0,0,33,10,0,102,255,58,0,0,0,
  0,0,0,0,208,168,0,0,215,142,249,39,0,88,255,32,0,0,0,0,0,0,0,0,0,0,0,0,0,196,192,0,
  0,0,0,0,0,0,0,192,196,0,0,0,0,136,255,93,0,0,0,0,0,0,0,200,172,0,0,0,10,222,241,255,
  64,0,0,0,63,184,239,248,217,135,14,0,0,0,0,0,212,176,0,0,0,0,94,255,150,0,0,212,211,112,112,112,
  112,112,36,0,0,74,255,112,0,0,0,0,23,222,199,2,0,0,91,255,93,0,0,158,239,114,232,197,0,0,0,0,
  0,0,0,0,208,168,0,0,132,250,210,0,0,88,255,32,0,160,255,255,255,255,255,255,255,255,116,0,0,196,192,0,
  0,0,0,0,0,0,0,192,196,0,0,0,0,12,232,229,10,0,0,0,0,0,0,200,172,0,0,0,0,70,255,255,
  64,0,0,67,252,163,77,65,113,235,201,3,0,0,0,0,212,176,0,0,0,0,0,177,255,74,0,212,255,255,255,255,
  255,255,84,0,0,0,126,254,167,78,63,112,228,218,33,0,0,0,0,143,253,157,75,66,197,255,254,51,0,0,0,0,
  0,0,0,0,208,168,0,0,49,255,126,0,0,88,255,32,0,35,56,56,56,224,190,56,56,56,25,0,0,196,192,0,
  0,0,0,0,0,0,0,192,196,0,0,0,0,0,102,255,128,0,0,0,0,0,0,200,172,0,0,0,0,0,162,255,
  64,0,0,183,195,0,0,0,0,72,255,78,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,67,179,232,246,212,126,14,0,0,0,0,0,0,77,186,235,244,211,128,179,237,110,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,172,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,192,196,0,0,0,0,0,3,212,245,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,205,198,0,0,0,0,3,122,48,0,192,196,0,0,0,0,0,64,255,68,0,189,226,1,0,0,0,0,0,
  45,255,92,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,96,0,0,0,
  0,172,220,0,0,0,0,118,255,162,0,0,0,0,182,202,0,0,0,0,0,216,172,0,0,0,0,0,4,255,255,255,
  255,255,255,255,255,48,0,0,0,0,0,0,0,0,0,0,0,0,0,31,242,188,1,0,0,0,2,190,220,12,0,0,
  0,0,0,132,255,187,92,27,0,0,0,0,0,192,196,0,0,0,0,0,64,255,68,0,94,255,58,0,0,0,0,0,
  136,241,10,0,163,253,53,0,0,0,0,0,136,253,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,107,255,21,0,0,0,187,237,230,0,0,0,2,239,135,0,0,0,0,0,216,172,0,0,0,0,0,0,56,56,56,
  56,56,67,234,229,16,0,176,255,255,104,0,13,212,209,1,0,0,0,0,100,255,106,0,0,0,121,251,54,0,0,0,
  0,0,0,5,155,252,255,255,217,135,19,0,0,192,196,0,0,0,0,0,64,255,68,0,11,243,145,0,0,0,0,1,
  225,156,0,0,20,235,206,3,0,0,0,45,251,141,0,0,236,255,255,48,0,220,71,0,0,0,0,0,0,0,0,0,
  0,42,255,77,0,0,8,247,126,255,44,0,0,45,255,68,0,0,0,0,0,216,172,0,0,0,0,0,0,0,0,0,
  0,0,165,253,64,0,0,38,56,255,104,0,0,33,235,81,0,0,0,0,0,181,244,34,0,54,250,123,0,0,0,0,
  0,0,0,0,0,26,103,172,238,255,232,35,0,192,196,0,0,0,0,0,64,255,68,0,0,161,230,2,0,0,0,62,
  255,61,0,0,0,93,255,112,0,0,2,199,219,9,0,0,236,152,56,10,0,149,141,0,0,0,0,0,0,0,0,0,
  0,0,233,134,0,0,68,252,18,236,113,0,0,105,248,9,0,0,0,0,0,216,172,0,0,0,0,0,0,0,0,0,
  0,99,255,127,0,0,0,0,0,255,104,0,0,0,22,24,0,0,0,0,0,25,238,192,11,219,194,2,0,0,0,0,
  0,0,0,0,0,0,0,0,3,97,250,165,0,192,196,0,0,0,0,0,64,255,68,0,0,66,255,63,0,0,0,153,
  220,0,0,0,0,0,186,243,27,0,106,254,61,0,0,0,236,124,0,0,0,78,212,0,0,0,0,0,0,0,0,0,
  0,0,169,191,0,0,136,200,0,170,182,0,0,164,190,0,0,0,0,0,0,216,172,0,0,0,0,0,0,0,0,0,
  41,245,191,2,0,0,0,0,0,255,104,0,0,0,0,0,0,0,0,0,0,0,90,255,207,239,30,0,0,0,0,0,
  0,0,45,235,64,0,0,0,0,0,175,206,0,192,196,0,0,0,0,0,64,255,68,0,0,1,225,151,0,0,6,238,
  125,0,0,0,0,0,33,245,165,20,238,145,0,0,0,0,236,124,0,0,0,13,250,27,0,0,0,0,0,0,0,0,
  0,0,104,244,3,0,205,132,0,102,244,6,0,224,123,0,0,0,0,0,0,216,172,0,0,0,0,0,0,0,0,8,
  210,235,26,0,0,0,0,0,0,255,104,0,240,120,0,0,0,0,0,0,0,0,0,183,255,109,0,0,0,0,0,0,
  0,0,12,240,173,0,0,0,0,3,209,162,0,191,196,0,0,0,0,0,64,255,67,0,0,0,133,234,3,0,79,254,
  31,0,0,0,0,0,0,116,255,194,221,11,0,0,0,0,236,124,0,0,0,0,192,97,0,0,0,0,0,0,0,0,
  0,0,40,255,49,19,253,63,0,34,255,62,27,255,56,0,0,0,0,0,0,216,172,0,0,0,0,0,0,0,0,151,
  254,73,0,0,0,0,0,0,0,255,104,0,52,26,0,0,0,0,0,0,0,0,27,237,255,203,4,0,0,0,0,0,
  0,0,0,101,255,189,90,61,86,188,239,38,0,181,203,0,0,0,0,0,70,255,57,0,0,0,38,255,69,0,169,190,
  0,0,0,0,0,0,0,3,205,255,64,0,0,0,0,0,236,124,0,0,0,0,121,168,0,0,0,0,0,0,0,0,
  0,0,0,231,106,86,244,6,0,0,222,124,87,241,3,0,0,0,0,0,0,216,172,0,0,0,0,0,0,0,83,255,
  138,0,0,0,0,0,0,0,0,255,104,0,0,0,0,0,0,0,0,0,0,1,187,230,98,255,126,0,0,0,0,0,
  0,0,0,0,69,181,234,250,232,164,36,0,0,158,227,0,0,0,0,0,97,255,34,0,0,0,0,199,156,13,246,94,
  0,0,0,0,0,0,0,0,140,248,0,0,0,0,0,0,236,124,0,0,0,0,50,236,2,0,0,0,0,0,0,0,
  0,0,0,166,159,151,183,0,0,0,154,182,147,178,0,0,0,0,0,0,0,216,172,0,0,0,0,0,0,31,239,200,
  5,0,0,0,0,0,0,0,0,255,104,0,240,120,0,0,0,0,0,0,0,114,255,75,0,169,250,50,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,96,255,52,0,0,0,0,176,227,0,0,0,0,0,105,234,89,243,11,
  0,0,0,0,0,0,0,0,140,248,0,0,0,0,0,0,236,124,0,0,0,0,1,234,53,0,0,0,0,0,0,0,
  0,0,0,102,209,211,114,0,0,0,86,227,203,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,198,239,32,
  0,0,0,0,0,0,0,0,0,255,104,0,240,120,0,0,0,0,0,0,46,248,155,0,0,19,232,213,7,0,0,0,
  0,17,245,134,0,0,0,0,0,0,0,0,0,6,211,232,108,63,85,172,253,88,0,0,0,0,0,17,248,218,159,0,
  0,0,0,0,0,0,0,0,140,248,0,0,0,0,0,0,236,124,0,0,0,0,0,164,124,0,0,0,0,0,0,0,
  0,0,0,37,252,254,46,0,0,0,19,253,251,44,0,0,0,0,17,148,226,250,233,155,12,0,0,0,127,255,131,56,
  56,56,56,56,56,21,0,0,0,255,104,0,240,120,0,0,0,0,0,8,211,222,12,0,0,0,79,255,140,0,0,0,
  0,115,244,235,8,0,0,0,0,0,0,0,0,0,16,143,221,248,237,189,71,0,0,0,0,0,0,0,171,255,63,0,
  0,0,0,0,0,0,0,0,140,248,0,0,0,0,0,0,236,124,0,0,0,0,0,93,195,0,0,0,0,0,0,0,
  0,0,0,0,228,233,1,0,0,0,0,206,232,0,0,0,0,0,188,224,90,64,120,251,132,0,0,0,176,255,255,255,
  255,255,255,255,255,96,0,0,0,255,104,0,240,120,0,0,0,0,0,145,253,62,0,0,0,0,0,162,253,62,0,0,
  2,222,111,230,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,140,248,0,0,0,0,0,0,236,124,0,0,0,0,0,23,250,14,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,187,74,0,0,0,181,193,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,255,104,0,240,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  77,247,16,133,206,0,0,0,13,56,56,56,56,56,56,56,56,56,5,0,244,116,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,236,124,0,0,0,0,0,0,207,80,0,0,0,0,0,0,
  0,0,7,144,233,243,158,132,212,0,0,0,0,0,0,0,0,0,0,1,34,71,116,221,199,0,0,0,3,122,221,246,
  208,80,0,0,252,108,0,0,0,255,104,0,240,120,0,0,0,0,0,0,0,0,0,168,192,0,0,0,244,116,0,0,
  186,165,0,33,254,60,0,0,60,255,255,255,255,255,255,255,255,255,24,0,244,116,0,0,0,0,0,0,0,0,1,118,
  221,249,211,82,0,0,0,0,30,197,248,216,0,0,0,0,236,124,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,162,243,109,75,190,248,212,0,0,0,0,0,0,0,0,0,85,226,255,235,182,210,200,0,0,0,146,249,124,67,
  153,252,60,0,252,108,0,38,56,255,104,0,240,120,0,0,0,0,0,0,0,0,0,168,192,0,0,0,53,25,0,40,
  254,66,0,0,186,170,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,116,0,0,0,0,0,0,0,0,139,251,
  129,70,148,254,78,0,0,0,141,242,76,53,0,0,0,0,236,152,56,10,0,244,116,0,0,0,0,0,0,0,0,0,
  0,34,254,100,0,0,8,230,212,0,0,0,0,0,0,0,0,44,251,154,28,0,0,174,200,0,0,18,252,125,0,0,
  0,191,122,0,252,108,0,176,255,255,104,0,240,120,0,0,0,0,0,0,0,0,0,168,192,0,0,0,0,0,0,60,
  122,1,0,0,54,123,2,0,240,120,0,0,0,0,0,0,0,0,0,0,244,136,174,247,225,120,1,0,0,24,251,130,
  0,0,0,165,214,0,0,0,159,201,0,0,0,0,0,0,236,255,255,48,0,244,116,0,0,0,0,0,0,0,0,0,
  0,97,255,20,0,0,0,154,212,0,0,0,0,0,0,0,0,98,255,34,0,0,13,232,202,0,0,73,255,48,0,0,
  0,0,0,0,252,108,0,0,0,0,0,0,240,120,0,0,0,0,8,145,234,240,136,169,192,0,0,0,244,116,0,0,
  0,0,0,0,0,0,0,0,240,120,0,0,0,0,0,0,0,0,0,0,244,252,167,72,133,254,120,0,0,84,255,57,
  4,4,4,89,255,25,0,220,255,255,255,104,0,0,0,0,0,0,0,0,0,244,116,0,0,0,0,0,0,0,0,0,
  0,117,253,1,0,0,0,131,212,0,0,0,0,0,0,0,0,48,254,171,66,86,204,235,213,0,0,91,255,26,0,0,
  0,0,0,0,252,108,0,0,0,0,0,0,0,0,0,0,0,0,168,242,105,77,194,250,192,0,0,0,244,116,0,244,
  107,177,246,225,115,0,0,0,240,120,0,0,0,0,0,0,0,0,0,0,244,201,0,0,0,156,236,3,0,103,255,255,
  255,255,255,255,255,50,0,48,181,212,56,22,0,244,98,165,242,237,149,7,0,244,135,165,242,238,148,8,0,0,0,0,
  0,90,255,20,0,0,0,152,212,0,0,0,0,0,0,0,0,0,98,220,249,214,102,88,251,20,0,76,255,47,0,0,
  0,48,49,0,252,108,0,0,4,115,215,247,215,100,0,0,0,34,255,102,0,0,12,237,192,0,0,0,244,116,0,244,
  241,171,72,136,254,113,0,0,240,120,0,1,166,241,52,0,0,0,0,0,244,116,0,0,0,77,255,44,0,88,255,80,
  52,52,52,52,52,11,0,0,160,200,0,0,0,244,240,150,68,117,253,117,0,244,253,152,66,119,254,124,0,0,0,0,
  0,33,252,98,0,0,5,225,212,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,251,123,0,0,
  0,202,166,0,252,108,0,0,159,247,121,70,144,255,115,0,0,93,255,26,0,0,0,167,192,0,0,0,244,116,0,244,
  206,1,0,0,157,233,1,0,240,120,0,146,246,61,0,0,0,0,0,0,244,93,0,0,0,55,255,59,0,30,253,102,
  0,0,0,95,173,10,0,0,160,200,0,0,0,244,183,0,0,0,186,191,0,244,187,0,0,0,187,190,0,0,0,0,
  0,0,158,241,106,73,181,253,210,0,244,101,170,244,230,108,25,177,245,220,81,0,0,0,0,0,0,0,147,247,118,68,
  154,249,52,0,252,108,0,38,255,111,0,0,0,155,242,10,0,110,255,6,0,0,0,143,192,0,0,0,244,116,0,244,
  117,0,0,0,76,255,40,0,240,120,123,249,71,0,0,0,0,0,0,0,244,110,0,0,0,78,255,38,0,0,152,243,
  119,65,114,247,159,0,0,0,160,200,0,0,0,244,126,0,0,0,158,202,0,244,127,0,0,0,154,206,0,0,0,0,
  0,0,10,150,237,243,155,167,199,0,244,242,139,66,165,254,216,128,67,188,243,17,0,0,0,0,0,0,3,127,226,246,
  202,66,0,0,252,108,0,99,255,26,0,0,0,67,255,60,0,91,255,29,0,0,0,163,192,0,0,0,244,116,0,244,
  91,0,0,0,55,255,58,0,240,206,255,164,0,0,0,0,0,0,0,0,244,182,0,0,0,161,229,1,0,0,3,125,
  223,249,223,130,5,0,0,0,160,200,0,0,0,244,116,0,0,0,156,204,0,244,116,0,0,0,152,208,0,0,0,0,
  0,18,90,15,0,0,0,197,163,0,244,184,0,0,27,255,164,0,0,47,255,60,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,252,108,0,116,255,4,0,0,0,44,255,74,0,28,254,112,0,0,8,230,192,0,0,0,244,116,0,244,
  110,0,0,0,78,255,36,0,240,254,184,251,46,0,0,0,0,0,0,0,244,246,143,66,140,254,98,0,0,0,0,0,
  0,0,0,0,0,0,0,0,160,200,0,0,0,244,116,0,0,0,156,204,0,244,116,0,0,0,152,208,0,0,0,0,
  0,9,239,178,71,67,150,253,60,0,244,129,0,0,4,255,110,0,0,28,255,76,0,0,8,145,234,240,144,136,192,0,
  0,0,0,0,252,108,0,98,255,26,0,0,0,68,255,55,0,0,149,246,114,74,185,247,192,0,0,0,244,116,0,244,
  186,0,0,0,159,227,0,0,240,143,6,217,197,1,0,0,0,0,0,0,244,115,181,248,222,99,0,0,0,248,122,213,
  245,87,0,0,0,0,0,0,160,200,0,0,0,244,116,0,0,0,156,204,0,244,116,0,0,0,152,208,0,0,0,0,
  0,0,54,187,239,245,197,70,0,0,244,116,0,0,4,255,100,0,0,28,255,76,0,0,167,243,108,77,200,239,192,0,
  0,0,0,0,252,108,0,38,255,111,0,0,0,155,244,8,0,0,3,132,231,244,157,147,192,0,0,0,244,116,0,244,
  254,152,70,138,254,96,0,0,240,120,0,72,255,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,245,100,
  84,23,0,0,0,0,0,0,160,200,0,0,0,244,116,0,0,0,156,204,0,244,116,0,0,0,152,208,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,244,116,0,0,4,255,100,0,0,28,255,76,0,32,255,106,0,0,15,240,192,0,
  0,0,0,0,0,0,0,0,161,247,120,69,142,254,120,0,0,0,0,0,0,0,0,0,0,0,0,0,251,106,0,244,
  135,180,247,215,93,0,0,0,240,120,0,0,176,237,21,0,0,58,195,244,238,170,30,0,0,136,180,0,0,248,173,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,244,116,0,0,0,156,204,0,244,116,0,0,0,152,208,0,0,0,0,
  0,159,217,0,0,0,0,203,163,0,244,116,0,0,4,255,100,0,0,28,255,76,0,90,255,31,0,0,0,166,192,0,
  0,0,1,0,0,0,0,0,5,131,226,248,211,99,0,0,0,85,255,104,0,0,88,255,85,0,50,120,255,72,0,244,
  116,0,0,0,0,0,0,0,240,120,0,0,33,247,161,0,20,239,159,66,84,222,199,0,0,136,180,0,0,248,134,0,
  0,0,0,252,108,0,0,0,168,192,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,70,255,46,0,0,34,255,73,0,244,116,0,0,4,255,100,0,0,28,255,76,0,107,255,10,0,0,0,140,192,0,
  0,71,155,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,175,237,20,21,235,167,0,0,149,243,166,5,0,244,
  116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,255,46,0,0,63,129,2,0,136,180,0,0,248,112,0,
  0,0,0,252,108,0,0,0,168,192,0,208,160,0,0,18,254,162,0,0,21,254,75,0,0,0,67,221,246,0,0,0,
  0,3,232,131,0,0,120,235,4,0,244,116,0,0,4,255,100,0,0,28,255,76,0,87,255,33,0,0,0,159,192,0,
  0,176,184,0,0,0,141,238,6,0,0,0,186,173,0,0,0,0,25,239,152,165,230,18,0,0,0,0,0,0,0,244,
  116,0,0,0,0,0,0,0,159,243,125,0,0,0,0,0,16,239,233,146,71,6,0,0,0,136,180,0,0,248,112,0,
  0,0,0,252,108,0,0,0,168,192,0,136,225,0,0,80,255,222,0,0,90,247,9,0,0,0,202,185,60,0,0,0,
  0,0,146,216,0,0,206,151,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,252,116,0,0,7,227,192,0,
  0,176,184,0,0,0,47,255,77,0,0,24,252,79,0,0,0,0,0,98,253,255,75,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,36,118,254,32,0,0,0,0,0,45,171,244,255,238,117,0,0,136,180,0,0,248,112,0,
  0,0,0,252,108,0,0,0,168,192,0,63,255,35,0,144,206,255,27,0,160,183,0,0,0,0,236,103,0,0,0,0,
  0,0,56,255,45,36,255,61,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,143,247,116,72,182,254,192,0,
  184,255,255,255,32,0,0,208,167,0,0,112,236,5,0,0,0,0,0,16,246,240,16,0,0,0,96,255,255,255,255,255,
  255,104,0,0,0,0,0,0,0,15,255,66,0,0,0,0,0,0,0,6,68,178,255,55,0,136,180,0,0,248,112,0,
  0,0,0,252,108,0,0,0,168,192,0,5,241,101,0,208,102,242,87,0,229,109,0,0,0,0,241,96,0,0,0,0,
  0,0,0,222,128,121,226,1,0,0,20,170,242,235,169,75,12,60,133,0,0,0,0,0,2,127,231,244,155,175,192,0,
  40,193,199,56,7,0,0,114,245,11,0,204,149,0,0,0,0,0,0,155,232,233,158,0,0,0,21,56,56,56,56,199,
  234,28,0,0,0,0,0,0,0,10,255,73,0,0,0,0,83,233,15,0,0,31,255,85,0,136,180,0,0,248,112,0,
  0,0,0,251,111,0,0,0,180,192,0,0,174,166,18,254,38,185,148,44,255,35,0,0,0,3,252,83,0,0,0,0,
  0,0,0,133,203,203,139,0,0,0,83,154,69,91,182,252,255,246,98,0,0,0,0,0,0,0,0,0,0,168,192,0,
  0,176,184,0,0,0,0,23,251,89,39,255,56,0,0,0,0,0,65,255,91,93,255,68,0,0,0,0,0,0,109,252,
  67,0,0,0,0,0,0,0,0,0,249,88,0,0,0,0,25,240,190,75,71,182,239,20,0,136,180,0,0,0,0,0,
  0,0,0,237,139,0,0,8,232,192,0,0,102,231,78,231,0,122,209,113,218,0,0,0,6,112,244,22,0,0,0,0,
  0,0,0,43,254,254,49,0,0,0,7,0,0,0,0,17,43,9,0,0,0,0,0,0,0,0,0,0,0,168,192,0,
  0,176,184,0,0,0,0,0,181,173,122,219,0,0,0,0,0,10,220,190,0,0,193,222,11,0,0,0,0,61,250,122,
  0,0,0,0,0,0,0,0,0,0,175,185,21,0,0,0,0,57,191,240,244,188,50,0,0,136,180,0,0,0,0,0,
  0,0,0,164,240,93,72,187,236,192,0,0,29,255,178,170,0,60,254,200,144,0,0,0,140,246,58,0,0,0,0,0,
  0,0,0,0,209,216,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,192,0,
  0,176,184,0,0,0,0,0,87,244,205,126,0,0,0,0,0,141,249,40,0,0,43,250,144,0,0,0,27,232,178,1,
  0,0,0,0,0,0,0,0,0,0,13,201,228,0,0,0,0,0,0,0,0,0,0,0,0,136,180,0,0,0,0,0,
  0,0,0,23,173,245,234,132,130,192,0,0,0,213,255,108,0,6,247,255,70,0,0,0,34,175,190,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,176,184,0,0,0,0,0,8,240,255,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,200,220,16,0,
  0,0,0,0,0,0,0,0,0,0,102,226,70,0,0,0,0,0,0,0,0,0,0,0,0,136,180,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,140,255,46,0,0,191,245,7,0,0,0,0,25,255,48,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,173,184,0,0,0,0,0,0,175,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,155,246,48,0,0,
  0,0,0,0,0,0,0,0,0,0,214,111,0,0,0,0,0,0,0,0,0,0,0,0,0,136,180,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,249,86,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,157,223,65,10,0,0,0,9,237,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,255,128,51,56,56,
  56,36,0,0,0,0,0,0,0,1,253,79,0,0,0,0,0,0,0,0,0,0,0,0,0,136,180,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,241,98,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,57,225,248,58,0,17,127,193,233,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,255,255,255,255,255,
  255,168,0,0,0,0,0,0,0,8,255,72,0,0,0,0,0,0,0,0,0,0,0,0,0,136,180,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,237,100,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,9,234,226,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,12,255,69,0,0,0,0,0,0,0,0,0,0,0,0,0,136,180,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,107,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,22,255,58,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,171,193,61,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,37,134,249,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,214,245,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,159,240,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, 
 16.000000f, 18.400000f, 0.530000f, 14.480000f, -3.390000f, 96, 
 {
  {L'\0', 0, 0, 0, 0, 0.000000f, 0.000000f, 0.023438f, 0.023438f, 0.031250f, 0.031250f, 0, { } },
  {L' ', 0, 0, 0, 0, 4.453125f, 0.000000f, 0.046875f, 0.007812f, 0.046875f, 0.007812f, 5, { {L'A', -0.882812f}, {L'L', -0.593750f}, {L'P', -0.289062f}, {L'T', -0.289062f}, {L'Y', -0.289062f}} },
  {L'!', 3, 12, 1, 12, 4.453125f, 0.000000f, 0.054688f, 0.007812f, 0.078125f, 0.101562f, 0, { } },
  {L'"', 5, 4, 0, 12, 5.687500f, 0.000000f, 0.085938f, 0.007812f, 0.125000f, 0.039062f, 0, { } },
  {L'#', 9, 12, 0, 12, 8.906250f, 0.000000f, 0.132812f, 0.007812f, 0.203125f, 0.101562f, 0, { } },
  {L'$', 9, 15, 0, 13, 8.906250f, 0.000000f, 0.210938f, 0.007812f, 0.281250f, 0.125000f, 0, { } },
  {L'%', 14, 12, 0, 12, 14.234375f, 0.000000f, 0.289062f, 0.007812f, 0.398438f, 0.101562f, 0, { } },
  {L'&', 11, 13, 0, 12, 10.671875f, 0.000000f, 0.406250f, 0.007812f, 0.492188f, 0.109375f, 0, { } },
  {L'\'', 3, 4, 0, 12, 3.062500f, 0.000000f, 0.500000f, 0.007812f, 0.523438f, 0.039062f, 0, { } },
  {L'(', 5, 15, 0, 12, 5.328125f, 0.000000f, 0.531250f, 0.007812f, 0.570312f, 0.125000f, 0, { } },
  {L')', 5, 15, 0, 12, 5.328125f, 0.000000f, 0.578125f, 0.007812f, 0.617188f, 0.125000f, 0, { } },
  {L'*', 6, 6, 0, 12, 6.234375f, 0.000000f, 0.625000f, 0.007812f, 0.671875f, 0.054688f, 0, { } },
  {L'+', 9, 8, 0, 10, 9.343750f, 0.000000f, 0.679688f, 0.007812f, 0.750000f, 0.070312f, 0, { } },
  {L',', 3, 5, 1, 2, 4.453125f, 0.000000f, 0.757812f, 0.007812f, 0.781250f, 0.046875f, 10, { {L'F', -1.773438f}, {L'P', -2.062500f}, {L'T', -1.773438f}, {L'V', -1.468750f}, {L'W', -0.882812f}, {L'Y', -2.062500f}, {L'r', -0.882812f}, {L'v', -1.187500f}, {L'w', -0.882812f}, {L'y', -1.187500f}} },
  {L'-', 5, 3, 0, 6, 5.328125f, 0.000000f, 0.789062f, 0.007812f, 0.828125f, 0.031250f, 4, { {L'T', -0.882812f}, {L'V', -0.882812f}, {L'W', -0.289062f}, {L'Y', -1.468750f}} },
  {L'.', 3, 2, 1, 2, 4.453125f, 0.000000f, 0.835938f, 0.007812f, 0.859375f, 0.023438f, 10, { {L'F', -1.773438f}, {L'P', -2.062500f}, {L'T', -1.773438f}, {L'V', -1.468750f}, {L'W', -0.882812f}, {L'Y', -2.062500f}, {L'r', -0.882812f}, {L'v', -1.187500f}, {L'w', -0.882812f}, {L'y', -1.187500f}} },
  {L'/', 5, 12, 0, 12, 4.453125f, 0.000000f, 0.867188f, 0.007812f, 0.906250f, 0.101562f, 0, { } },
  {L'0', 9, 12, 0, 12, 8.906250f, 0.000000f, 0.914062f, 0.007812f, 0.984375f, 0.101562f, 0, { } },
  {L'1', 5, 12, 1, 12, 8.906250f, 0.000000f, 0.789062f, 0.039062f, 0.828125f, 0.132812f, 1, { {L'1', -1.187500f}} },
  {L'2', 9, 12, 0, 12, 8.906250f, 0.000000f, 0.625000f, 0.078125f, 0.695312f, 0.171875f, 0, { } },
  {L'3', 9, 12, 0, 12, 8.906250f, 0.000000f, 0.703125f, 0.078125f, 0.773438f, 0.171875f, 0, { } },
  {L'4', 9, 12, 0, 12, 8.906250f, 0.000000f, 0.046875f, 0.109375f, 0.117188f, 0.203125f, 0, { } },
  {L'5', 9, 12, 0, 12, 8.906250f, 0.000000f, 0.125000f, 0.109375f, 0.195312f, 0.203125f, 0, { } },
  {L'6', 9, 12, 0, 12, 8.906250f, 0.000000f, 0.835938f, 0.109375f, 0.906250f, 0.203125f, 0, { } },
  {L'7', 9, 12, 0, 12, 8.906250f, 0.000000f, 0.914062f, 0.109375f, 0.984375f, 0.203125f, 0, { } },
  {L'8', 9, 12, 0, 12, 8.906250f, 0.000000f, 0.289062f, 0.109375f, 0.359375f, 0.203125f, 0, { } },
  {L'9', 9, 12, 0, 12, 8.906250f, 0.000000f, 0.367188f, 0.117188f, 0.437500f, 0.210938f, 0, { } },
  {L':', 3, 9, 1, 9, 4.453125f, 0.000000f, 0.500000f, 0.046875f, 0.523438f, 0.117188f, 4, { {L'T', -1.773438f}, {L'V', -0.593750f}, {L'W', -0.289062f}, {L'Y', -0.882812f}} },
  {L';', 3, 12, 1, 9, 4.453125f, 0.000000f, 0.007812f, 0.046875f, 0.031250f, 0.140625f, 4, { {L'T', -1.773438f}, {L'V', -0.593750f}, {L'W', -0.289062f}, {L'Y', -1.039062f}} },
  {L'<', 9, 10, 0, 11, 9.343750f, 0.000000f, 0.445312f, 0.125000f, 0.515625f, 0.203125f, 0, { } },
  {L'=', 9, 6, 0, 9, 9.343750f, 0.000000f, 0.203125f, 0.132812f, 0.273438f, 0.179688f, 0, { } },
  {L'>', 9, 10, 0, 11, 9.343750f, 0.000000f, 0.523438f, 0.132812f, 0.593750f, 0.210938f, 0, { } },
  {L'?', 9, 12, 0, 12, 8.906250f, 0.000000f, 0.601562f, 0.179688f, 0.671875f, 0.273438f, 0, { } },
  {L'@', 16, 15, 0, 12, 16.250000f, 0.000000f, 0.679688f, 0.179688f, 0.804688f, 0.296875f, 0, { } },
  {L'A', 12, 12, -1, 12, 10.671875f, 0.000000f, 0.039062f, 0.210938f, 0.132812f, 0.304688f, 7, { {L' ', -0.882812f}, {L'F', -0.882812f}, {L'P', -1.187500f}, {L'T', -1.187500f}, {L'V', -1.187500f}, {L'W', -0.593750f}, {L'Y', -1.187500f}} },
  {L'B', 9, 12, 1, 12, 10.671875f, 0.000000f, 0.203125f, 0.187500f, 0.273438f, 0.281250f, 0, { } },
  {L'C', 11, 12, 0, 12, 11.562500f, 0.000000f, 0.812500f, 0.210938f, 0.898438f, 0.304688f, 0, { } },
  {L'D', 10, 12, 1, 12, 11.562500f, 0.000000f, 0.281250f, 0.210938f, 0.359375f, 0.304688f, 0, { } },
  {L'E', 9, 12, 1, 12, 10.671875f, 0.000000f, 0.445312f, 0.210938f, 0.515625f, 0.304688f, 0, { } },
  {L'F', 9, 12, 1, 12, 9.781250f, 0.000000f, 0.906250f, 0.210938f, 0.976562f, 0.304688f, 0, { } },
  {L'G', 12, 12, 0, 12, 12.453125f, 0.000000f, 0.523438f, 0.281250f, 0.617188f, 0.375000f, 0, { } },
  {L'H', 10, 12, 1, 12, 11.562500f, 0.000000f, 0.140625f, 0.289062f, 0.218750f, 0.382812f, 0, { } },
  {L'I', 2, 12, 1, 12, 4.453125f, 0.000000f, 0.007812f, 0.148438f, 0.023438f, 0.242188f, 0, { } },
  {L'J', 7, 12, 0, 12, 8.000000f, 0.000000f, 0.367188f, 0.218750f, 0.421875f, 0.312500f, 0, { } },
  {L'K', 10, 12, 1, 12, 10.671875f, 0.000000f, 0.625000f, 0.304688f, 0.703125f, 0.398438f, 0, { } },
  {L'L', 8, 12, 1, 12, 8.906250f, 0.000000f, 0.710938f, 0.304688f, 0.773438f, 0.398438f, 0, { } },
  {L'M', 12, 12, 1, 12, 13.328125f, 0.000000f, 0.031250f, 0.312500f, 0.125000f, 0.406250f, 0, { } },
  {L'N', 10, 12, 1, 12, 11.562500f, 0.000000f, 0.429688f, 0.312500f, 0.507812f, 0.406250f, 0, { } },
  {L'O', 12, 12, 0, 12, 12.453125f, 0.000000f, 0.781250f, 0.312500f, 0.875000f, 0.406250f, 1, { {L'T', -0.289062f}} },
  {L'P', 9, 12, 1, 12, 10.671875f, 0.000000f, 0.226562f, 0.312500f, 0.296875f, 0.406250f, 0, { } },
  {L'Q', 12, 13, 0, 12, 12.453125f, 0.000000f, 0.882812f, 0.312500f, 0.976562f, 0.414062f, 0, { } },
  {L'R', 11, 12, 1, 12, 11.562500f, 0.000000f, 0.304688f, 0.320312f, 0.390625f, 0.414062f, 0, { } },
  {L'S', 10, 12, 0, 12, 10.671875f, 0.000000f, 0.515625f, 0.382812f, 0.593750f, 0.476562f, 0, { } },
  {L'T', 10, 12, 0, 12, 9.781250f, 0.000000f, 0.132812f, 0.390625f, 0.210938f, 0.484375f, 4, { {L' ', -0.289062f}, {L'A', -1.187500f}, {L'L', -1.187500f}, {L'R', -0.289062f}} },
  {L'U', 10, 12, 1, 12, 11.562500f, 0.000000f, 0.601562f, 0.406250f, 0.679688f, 0.500000f, 0, { } },
  {L'V', 11, 12, 0, 12, 10.671875f, 0.000000f, 0.687500f, 0.406250f, 0.773438f, 0.500000f, 3, { {L'A', -1.187500f}, {L'L', -1.187500f}, {L'R', -0.289062f}} },
  {L'W', 15, 12, 0, 12, 15.109375f, 0.000000f, 0.007812f, 0.414062f, 0.125000f, 0.507812f, 3, { {L'A', -0.593750f}, {L'L', -1.187500f}, {L'R', -0.289062f}} },
  {L'X', 11, 12, 0, 12, 10.671875f, 0.000000f, 0.398438f, 0.414062f, 0.484375f, 0.507812f, 0, { } },
  {L'Y', 11, 12, 0, 12, 10.671875f, 0.000000f, 0.781250f, 0.414062f, 0.867188f, 0.507812f, 4, { {L' ', -0.289062f}, {L'A', -1.187500f}, {L'L', -1.187500f}, {L'R', -0.289062f}} },
  {L'Z', 10, 12, 0, 12, 9.781250f, 0.000000f, 0.218750f, 0.414062f, 0.296875f, 0.507812f, 0, { } },
  {L'[', 4, 15, 1, 12, 4.453125f, 0.000000f, 0.875000f, 0.421875f, 0.906250f, 0.539062f, 0, { } },
  {L'\\', 5, 12, 0, 12, 4.453125f, 0.000000f, 0.914062f, 0.421875f, 0.953125f, 0.515625f, 0, { } },
  {L']', 4, 15, 0, 12, 4.453125f, 0.000000f, 0.304688f, 0.421875f, 0.335938f, 0.539062f, 0, { } },
  {L'^', 8, 7, 0, 12, 7.515625f, 0.000000f, 0.492188f, 0.484375f, 0.554688f, 0.539062f, 0, { } },
  {L'_', 11, 2, -1, -1, 8.906250f, 0.000000f, 0.562500f, 0.507812f, 0.648438f, 0.523438f, 0, { } },
  {L'`', 4, 3, 0, 12, 5.328125f, 0.000000f, 0.343750f, 0.421875f, 0.375000f, 0.445312f, 0, { } },
  {L'a', 9, 9, 0, 9, 8.906250f, 0.000000f, 0.132812f, 0.492188f, 0.203125f, 0.562500f, 4, { {L'T', -1.773438f}, {L'V', -1.187500f}, {L'W', -0.593750f}, {L'Y', -1.187500f}} },
  {L'b', 8, 12, 1, 12, 8.906250f, 0.000000f, 0.656250f, 0.507812f, 0.718750f, 0.601562f, 0, { } },
  {L'c', 8, 9, 0, 9, 8.000000f, 0.000000f, 0.210938f, 0.515625f, 0.273438f, 0.585938f, 1, { {L'T', -1.773438f}} },
  {L'd', 8, 12, 0, 12, 8.906250f, 0.000000f, 0.382812f, 0.515625f, 0.445312f, 0.609375f, 0, { } },
  {L'e', 9, 9, 0, 9, 8.906250f, 0.000000f, 0.726562f, 0.515625f, 0.796875f, 0.585938f, 4, { {L'T', -1.773438f}, {L'V', -0.882812f}, {L'W', -0.289062f}, {L'Y', -1.468750f}} },
  {L'f', 5, 12, 0, 12, 4.453125f, 0.000000f, 0.804688f, 0.515625f, 0.843750f, 0.609375f, 1, { {L'f', -0.289062f}} },
  {L'g', 8, 12, 0, 9, 8.906250f, 0.000000f, 0.007812f, 0.515625f, 0.070312f, 0.609375f, 0, { } },
  {L'h', 7, 12, 1, 12, 8.906250f, 0.000000f, 0.914062f, 0.523438f, 0.968750f, 0.617188f, 0, { } },
  {L'i', 2, 12, 1, 12, 3.562500f, 0.000000f, 0.343750f, 0.453125f, 0.359375f, 0.546875f, 3, { {L'T', -0.593750f}, {L'V', -0.289062f}, {L'Y', -0.593750f}} },
  {L'j', 4, 15, -1, 12, 3.562500f, 0.000000f, 0.453125f, 0.515625f, 0.484375f, 0.632812f, 0, { } },
  {L'k', 7, 12, 1, 12, 8.000000f, 0.000000f, 0.562500f, 0.531250f, 0.617188f, 0.625000f, 0, { } },
  {L'l', 2, 12, 1, 12, 3.562500f, 0.000000f, 0.281250f, 0.515625f, 0.296875f, 0.609375f, 0, { } },
  {L'm', 12, 9, 1, 9, 13.328125f, 0.000000f, 0.078125f, 0.570312f, 0.171875f, 0.640625f, 0, { } },
  {L'n', 7, 9, 1, 9, 8.906250f, 0.000000f, 0.851562f, 0.546875f, 0.906250f, 0.617188f, 0, { } },
  {L'o', 9, 9, 0, 9, 8.906250f, 0.000000f, 0.304688f, 0.554688f, 0.375000f, 0.625000f, 4, { {L'T', -1.773438f}, {L'V', -0.882812f}, {L'W', -0.289062f}, {L'Y', -1.468750f}} },
  {L'p', 8, 12, 1, 9, 8.906250f, 0.000000f, 0.492188f, 0.546875f, 0.554688f, 0.640625f, 1, { {L'Y', -1.187500f}} },
  {L'q', 8, 12, 0, 9, 8.906250f, 0.000000f, 0.179688f, 0.593750f, 0.242188f, 0.687500f, 1, { {L'Y', -1.468750f}} },
  {L'r', 5, 9, 1, 9, 5.328125f, 0.000000f, 0.726562f, 0.593750f, 0.765625f, 0.664062f, 3, { {L'T', -0.593750f}, {L'V', -0.593750f}, {L'W', -0.289062f}} },
  {L's', 8, 9, 0, 9, 8.000000f, 0.000000f, 0.625000f, 0.609375f, 0.687500f, 0.679688f, 1, { {L'T', -1.773438f}} },
  {L't', 5, 13, 0, 13, 4.453125f, 0.000000f, 0.250000f, 0.617188f, 0.289062f, 0.718750f, 0, { } },
  {L'u', 7, 9, 1, 9, 8.906250f, 0.000000f, 0.773438f, 0.617188f, 0.828125f, 0.687500f, 4, { {L'T', -0.593750f}, {L'V', -0.593750f}, {L'W', -0.289062f}, {L'Y', -0.882812f}} },
  {L'v', 8, 9, 0, 9, 8.000000f, 0.000000f, 0.007812f, 0.617188f, 0.070312f, 0.687500f, 2, { {L'A', -0.289062f}, {L'Y', -0.882812f}} },
  {L'w', 12, 9, 0, 9, 11.562500f, 0.000000f, 0.835938f, 0.625000f, 0.929688f, 0.695312f, 2, { {L'A', -0.289062f}, {L'T', -0.882812f}} },
  {L'x', 8, 9, 0, 9, 8.000000f, 0.000000f, 0.382812f, 0.617188f, 0.445312f, 0.687500f, 0, { } },
  {L'y', 8, 12, 0, 9, 8.000000f, 0.000000f, 0.296875f, 0.632812f, 0.359375f, 0.726562f, 5, { {L'A', -0.289062f}, {L'L', -0.593750f}, {L'T', -0.882812f}, {L'V', -0.593750f}, {L'W', -0.140625f}} },
  {L'z', 8, 9, 0, 9, 8.000000f, 0.000000f, 0.453125f, 0.648438f, 0.515625f, 0.718750f, 0, { } },
  {L'{', 5, 15, 0, 12, 5.343750f, 0.000000f, 0.937500f, 0.625000f, 0.976562f, 0.742188f, 0, { } },
  {L'|', 2, 15, 1, 12, 4.156250f, 0.000000f, 0.695312f, 0.609375f, 0.710938f, 0.726562f, 0, { } },
  {L'}', 5, 15, 0, 12, 5.343750f, 0.000000f, 0.562500f, 0.632812f, 0.601562f, 0.750000f, 0, { } },
  {L'~', 9, 4, 0, 8, 9.343750f, 0.000000f, 0.078125f, 0.648438f, 0.148438f, 0.679688f, 0, { } },
 }
};
#ifdef __cplusplus
}
#endif
